# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/account.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15gateway/account.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe4\x02\n\x07\x41\x63\x63ount\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12#\n\x13prometheus_endpoint\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12/\n\x1f\x61thena_cost_usage_report_bucket\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12:\n\x0c\x61\x63\x63ount_type\x18\x06 \x01(\x0e\x32\x1c.gateway.Account.AccountTypeB\x06\xe0\x41\x03\xe0\x41\x05\"]\n\x0b\x41\x63\x63ountType\x12\x1c\n\x18\x41\x43\x43OUNT_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDEVELOPER\x10\x01\x12\x0e\n\nENTERPRISE\x10\x02\x12\x11\n\rDEVELOPER_PRO\x10\x03\"W\n\x14\x43reateAccountRequest\x12&\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x03\xe0\x41\x02\x12\x17\n\naccount_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"&\n\x11GetAccountRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"r\n\x13ListAccountsRequest\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"g\n\x14ListAccountsResponse\x12\"\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x10.gateway.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\">\n\x14UpdateAccountRequest\x12&\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x03\xe0\x41\x02\")\n\x14\x44\x65leteAccountRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_ACCOUNT_ACCOUNTTYPE = _descriptor.EnumDescriptor(
  name='AccountType',
  full_name='gateway.Account.AccountType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACCOUNT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVELOPER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTERPRISE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVELOPER_PRO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=364,
  serialized_end=457,
)
_sym_db.RegisterEnumDescriptor(_ACCOUNT_ACCOUNTTYPE)


_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='gateway.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Account.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.Account.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Account.create_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prometheus_endpoint', full_name='gateway.Account.prometheus_endpoint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='athena_cost_usage_report_bucket', full_name='gateway.Account.athena_cost_usage_report_bucket', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_type', full_name='gateway.Account.account_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACCOUNT_ACCOUNTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=457,
)


_CREATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreateAccountRequest',
  full_name='gateway.CreateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='gateway.CreateAccountRequest.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='gateway.CreateAccountRequest.account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=546,
)


_GETACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetAccountRequest',
  full_name='gateway.GetAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetAccountRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=586,
)


_LISTACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListAccountsRequest',
  full_name='gateway.ListAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListAccountsRequest.page_size', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListAccountsRequest.page_token', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListAccountsRequest.filter', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListAccountsRequest.order_by', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=702,
)


_LISTACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='ListAccountsResponse',
  full_name='gateway.ListAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='gateway.ListAccountsResponse.accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListAccountsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListAccountsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=807,
)


_UPDATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='UpdateAccountRequest',
  full_name='gateway.UpdateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='gateway.UpdateAccountRequest.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=871,
)


_DELETEACCOUNTREQUEST = _descriptor.Descriptor(
  name='DeleteAccountRequest',
  full_name='gateway.DeleteAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteAccountRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=914,
)

_ACCOUNT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACCOUNT.fields_by_name['account_type'].enum_type = _ACCOUNT_ACCOUNTTYPE
_ACCOUNT_ACCOUNTTYPE.containing_type = _ACCOUNT
_CREATEACCOUNTREQUEST.fields_by_name['account'].message_type = _ACCOUNT
_LISTACCOUNTSRESPONSE.fields_by_name['accounts'].message_type = _ACCOUNT
_UPDATEACCOUNTREQUEST.fields_by_name['account'].message_type = _ACCOUNT
DESCRIPTOR.message_types_by_name['Account'] = _ACCOUNT
DESCRIPTOR.message_types_by_name['CreateAccountRequest'] = _CREATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['GetAccountRequest'] = _GETACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['ListAccountsRequest'] = _LISTACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['ListAccountsResponse'] = _LISTACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAccountRequest'] = _UPDATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAccountRequest'] = _DELETEACCOUNTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'gateway.account_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Account)
  })
_sym_db.RegisterMessage(Account)

CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'gateway.account_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'gateway.account_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'gateway.account_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)

ListAccountsResponse = _reflection.GeneratedProtocolMessageType('ListAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSRESPONSE,
  '__module__' : 'gateway.account_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListAccountsResponse)
  })
_sym_db.RegisterMessage(ListAccountsResponse)

UpdateAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTREQUEST,
  '__module__' : 'gateway.account_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateAccountRequest)
  })
_sym_db.RegisterMessage(UpdateAccountRequest)

DeleteAccountRequest = _reflection.GeneratedProtocolMessageType('DeleteAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTREQUEST,
  '__module__' : 'gateway.account_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteAccountRequest)
  })
_sym_db.RegisterMessage(DeleteAccountRequest)


DESCRIPTOR._options = None
_ACCOUNT.fields_by_name['name']._options = None
_ACCOUNT.fields_by_name['display_name']._options = None
_ACCOUNT.fields_by_name['create_time']._options = None
_ACCOUNT.fields_by_name['prometheus_endpoint']._options = None
_ACCOUNT.fields_by_name['athena_cost_usage_report_bucket']._options = None
_ACCOUNT.fields_by_name['account_type']._options = None
_CREATEACCOUNTREQUEST.fields_by_name['account']._options = None
_CREATEACCOUNTREQUEST.fields_by_name['account_id']._options = None
_GETACCOUNTREQUEST.fields_by_name['name']._options = None
_LISTACCOUNTSREQUEST.fields_by_name['page_size']._options = None
_LISTACCOUNTSREQUEST.fields_by_name['page_token']._options = None
_LISTACCOUNTSREQUEST.fields_by_name['filter']._options = None
_LISTACCOUNTSREQUEST.fields_by_name['order_by']._options = None
_UPDATEACCOUNTREQUEST.fields_by_name['account']._options = None
_DELETEACCOUNTREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/peft_merge_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/peft_merge_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgateway/peft_merge_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x03\n\x0cPeftMergeJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\npeft_model\x18\x07 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1b\n\x0cmerged_model\x18\t \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x35\n\x0bupdate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:\x83\x01\xea\x41q\n\x1d\x61pi.fireworks.ai/PeftMergeJob\x12\x33\x61\x63\x63ounts/{AccountId}/PeftMergeJobs/{PeftMergeJobId}*\rPeftMergeJobs2\x0cPeftMergeJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\",\n\x16GetPeftMergeJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"f\n\x19\x43reatePeftMergeJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x33\n\x0epeft_merge_job\x18\x02 \x01(\x0b\x32\x15.gateway.PeftMergeJobB\x04\xe2\x41\x01\x02\"\x91\x01\n\x18ListPeftMergeJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"x\n\x19ListPeftMergeJobsResponse\x12.\n\x0fpeft_merge_jobs\x18\x01 \x03(\x0b\x32\x15.gateway.PeftMergeJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"/\n\x19\x44\x65letePeftMergeJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.peft_merge_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_PEFTMERGEJOB'].fields_by_name['name']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_PEFTMERGEJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['state']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['status']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['peft_model']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['peft_model']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['merged_model']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['merged_model']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTMERGEJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_PEFTMERGEJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_PEFTMERGEJOB']._loaded_options = None
  _globals['_PEFTMERGEJOB']._serialized_options = b'\352Aq\n\035api.fireworks.ai/PeftMergeJob\0223accounts/{AccountId}/PeftMergeJobs/{PeftMergeJobId}*\rPeftMergeJobs2\014PeftMergeJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETPEFTMERGEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETPEFTMERGEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['peft_merge_job']._loaded_options = None
  _globals['_CREATEPEFTMERGEJOBREQUEST'].fields_by_name['peft_merge_job']._serialized_options = b'\342A\001\002'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTPEFTMERGEJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEPEFTMERGEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEPEFTMERGEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PEFTMERGEJOB']._serialized_start=180
  _globals['_PEFTMERGEJOB']._serialized_end=652
  _globals['_GETPEFTMERGEJOBREQUEST']._serialized_start=654
  _globals['_GETPEFTMERGEJOBREQUEST']._serialized_end=698
  _globals['_CREATEPEFTMERGEJOBREQUEST']._serialized_start=700
  _globals['_CREATEPEFTMERGEJOBREQUEST']._serialized_end=802
  _globals['_LISTPEFTMERGEJOBSREQUEST']._serialized_start=805
  _globals['_LISTPEFTMERGEJOBSREQUEST']._serialized_end=950
  _globals['_LISTPEFTMERGEJOBSRESPONSE']._serialized_start=952
  _globals['_LISTPEFTMERGEJOBSRESPONSE']._serialized_end=1072
  _globals['_DELETEPEFTMERGEJOBREQUEST']._serialized_start=1074
  _globals['_DELETEPEFTMERGEJOBREQUEST']._serialized_end=1121
# @@protoc_insertion_point(module_scope)



from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DatasetValidationFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DATASET_VALIDATION_FORMAT_UNSPECIFIED: _ClassVar[DatasetValidationFormat]
    DATASET_VALIDATION_FORMAT_CHAT: _ClassVar[DatasetValidationFormat]
    DATASET_VALIDATION_FORMAT_CHAT_RELAXED: _ClassVar[DatasetValidationFormat]
    DATASET_VALIDATION_FORMAT_RLOR: _ClassVar[DatasetValidationFormat]
    DATASET_VALIDATION_FORMAT_BATCH_INFERENCE_STRICT: _ClassVar[DatasetValidationFormat]
    DATASET_VALIDATION_FORMAT_BATCH_INFERENCE_ALLOW_TRAILING_ASSISTANT: _ClassVar[DatasetValidationFormat]

class DatasetValidationJobResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DATASET_VALIDATION_JOB_RESULT_UNSPECIFIED: _ClassVar[DatasetValidationJobResult]
    DATASET_VALIDATION_JOB_RESULT_SUCCESS: _ClassVar[DatasetValidationJobResult]
    DATASET_VALIDATION_JOB_RESULT_FAILURE: _ClassVar[DatasetValidationJobResult]
DATASET_VALIDATION_FORMAT_UNSPECIFIED: DatasetValidationFormat
DATASET_VALIDATION_FORMAT_CHAT: DatasetValidationFormat
DATASET_VALIDATION_FORMAT_CHAT_RELAXED: DatasetValidationFormat
DATASET_VALIDATION_FORMAT_RLOR: DatasetValidationFormat
DATASET_VALIDATION_FORMAT_BATCH_INFERENCE_STRICT: DatasetValidationFormat
DATASET_VALIDATION_FORMAT_BATCH_INFERENCE_ALLOW_TRAILING_ASSISTANT: DatasetValidationFormat
DATASET_VALIDATION_JOB_RESULT_UNSPECIFIED: DatasetValidationJobResult
DATASET_VALIDATION_JOB_RESULT_SUCCESS: DatasetValidationJobResult
DATASET_VALIDATION_JOB_RESULT_FAILURE: DatasetValidationJobResult

class DatasetValidationJob(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "created_by", "state", "status", "dataset_name", "format", "result", "validation_error", "dataset_names", "update_time", "rewards")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DATASET_NAME_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    DATASET_NAMES_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    created_by: str
    state: _status_pb2.JobState
    status: _status_pb2.Status
    dataset_name: str
    format: DatasetValidationFormat
    result: DatasetValidationJobResult
    validation_error: str
    dataset_names: _containers.RepeatedScalarFieldContainer[str]
    update_time: _timestamp_pb2.Timestamp
    rewards: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., state: _Optional[_Union[_status_pb2.JobState, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., dataset_name: _Optional[str] = ..., format: _Optional[_Union[DatasetValidationFormat, str]] = ..., result: _Optional[_Union[DatasetValidationJobResult, str]] = ..., validation_error: _Optional[str] = ..., dataset_names: _Optional[_Iterable[str]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., rewards: _Optional[_Iterable[str]] = ...) -> None: ...

class GetDatasetValidationJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateDatasetValidationJobRequest(_message.Message):
    __slots__ = ("parent", "dataset_validation_job", "dataset_validation_job_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    DATASET_VALIDATION_JOB_FIELD_NUMBER: _ClassVar[int]
    DATASET_VALIDATION_JOB_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    dataset_validation_job: DatasetValidationJob
    dataset_validation_job_id: str
    def __init__(self, parent: _Optional[str] = ..., dataset_validation_job: _Optional[_Union[DatasetValidationJob, _Mapping]] = ..., dataset_validation_job_id: _Optional[str] = ...) -> None: ...

class ListDatasetValidationJobsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListDatasetValidationJobsResponse(_message.Message):
    __slots__ = ("dataset_validation_jobs", "next_page_token", "total_size")
    DATASET_VALIDATION_JOBS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    dataset_validation_jobs: _containers.RepeatedCompositeFieldContainer[DatasetValidationJob]
    next_page_token: str
    total_size: int
    def __init__(self, dataset_validation_jobs: _Optional[_Iterable[_Union[DatasetValidationJob, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteDatasetValidationJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



from ..buf.validate import validate_pb2 as _validate_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NodePool(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "min_node_count", "max_node_count", "overprovision_node_count", "eks_node_pool", "fake_node_pool", "annotations", "state", "status", "node_pool_stats", "update_time")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[NodePool.State]
        CREATING: _ClassVar[NodePool.State]
        READY: _ClassVar[NodePool.State]
        DELETING: _ClassVar[NodePool.State]
        FAILED: _ClassVar[NodePool.State]
    STATE_UNSPECIFIED: NodePool.State
    CREATING: NodePool.State
    READY: NodePool.State
    DELETING: NodePool.State
    FAILED: NodePool.State
    class AnnotationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    MIN_NODE_COUNT_FIELD_NUMBER: _ClassVar[int]
    MAX_NODE_COUNT_FIELD_NUMBER: _ClassVar[int]
    OVERPROVISION_NODE_COUNT_FIELD_NUMBER: _ClassVar[int]
    EKS_NODE_POOL_FIELD_NUMBER: _ClassVar[int]
    FAKE_NODE_POOL_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NODE_POOL_STATS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    min_node_count: int
    max_node_count: int
    overprovision_node_count: int
    eks_node_pool: EksNodePool
    fake_node_pool: FakeNodePool
    annotations: _containers.ScalarMap[str, str]
    state: NodePool.State
    status: _status_pb2.Status
    node_pool_stats: NodePoolStats
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., min_node_count: _Optional[int] = ..., max_node_count: _Optional[int] = ..., overprovision_node_count: _Optional[int] = ..., eks_node_pool: _Optional[_Union[EksNodePool, _Mapping]] = ..., fake_node_pool: _Optional[_Union[FakeNodePool, _Mapping]] = ..., annotations: _Optional[_Mapping[str, str]] = ..., state: _Optional[_Union[NodePool.State, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., node_pool_stats: _Optional[_Union[NodePoolStats, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class EksNodePool(_message.Message):
    __slots__ = ("node_role", "instance_type", "spot", "node_group_name", "subnet_ids", "zone", "placement_group", "launch_template")
    NODE_ROLE_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    SPOT_FIELD_NUMBER: _ClassVar[int]
    NODE_GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    SUBNET_IDS_FIELD_NUMBER: _ClassVar[int]
    ZONE_FIELD_NUMBER: _ClassVar[int]
    PLACEMENT_GROUP_FIELD_NUMBER: _ClassVar[int]
    LAUNCH_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    node_role: str
    instance_type: str
    spot: bool
    node_group_name: str
    subnet_ids: _containers.RepeatedScalarFieldContainer[str]
    zone: str
    placement_group: str
    launch_template: str
    def __init__(self, node_role: _Optional[str] = ..., instance_type: _Optional[str] = ..., spot: bool = ..., node_group_name: _Optional[str] = ..., subnet_ids: _Optional[_Iterable[str]] = ..., zone: _Optional[str] = ..., placement_group: _Optional[str] = ..., launch_template: _Optional[str] = ...) -> None: ...

class FakeNodePool(_message.Message):
    __slots__ = ("machine_type", "num_nodes", "service_account")
    MACHINE_TYPE_FIELD_NUMBER: _ClassVar[int]
    NUM_NODES_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    machine_type: str
    num_nodes: int
    service_account: str
    def __init__(self, machine_type: _Optional[str] = ..., num_nodes: _Optional[int] = ..., service_account: _Optional[str] = ...) -> None: ...

class NodePoolStats(_message.Message):
    __slots__ = ("node_count", "ranks_per_node", "environment_count", "environment_ranks", "batch_job_count", "batch_job_ranks")
    class BatchJobCountEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    class BatchJobRanksEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    NODE_COUNT_FIELD_NUMBER: _ClassVar[int]
    RANKS_PER_NODE_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_COUNT_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_RANKS_FIELD_NUMBER: _ClassVar[int]
    BATCH_JOB_COUNT_FIELD_NUMBER: _ClassVar[int]
    BATCH_JOB_RANKS_FIELD_NUMBER: _ClassVar[int]
    node_count: int
    ranks_per_node: int
    environment_count: int
    environment_ranks: int
    batch_job_count: _containers.ScalarMap[str, int]
    batch_job_ranks: _containers.ScalarMap[str, int]
    def __init__(self, node_count: _Optional[int] = ..., ranks_per_node: _Optional[int] = ..., environment_count: _Optional[int] = ..., environment_ranks: _Optional[int] = ..., batch_job_count: _Optional[_Mapping[str, int]] = ..., batch_job_ranks: _Optional[_Mapping[str, int]] = ...) -> None: ...

class CreateNodePoolRequest(_message.Message):
    __slots__ = ("parent", "node_pool", "node_pool_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    NODE_POOL_FIELD_NUMBER: _ClassVar[int]
    NODE_POOL_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    node_pool: NodePool
    node_pool_id: str
    def __init__(self, parent: _Optional[str] = ..., node_pool: _Optional[_Union[NodePool, _Mapping]] = ..., node_pool_id: _Optional[str] = ...) -> None: ...

class GetNodePoolRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListNodePoolsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListNodePoolsResponse(_message.Message):
    __slots__ = ("node_pools", "next_page_token", "total_size")
    NODE_POOLS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    node_pools: _containers.RepeatedCompositeFieldContainer[NodePool]
    next_page_token: str
    total_size: int
    def __init__(self, node_pools: _Optional[_Iterable[_Union[NodePool, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateNodePoolRequest(_message.Message):
    __slots__ = ("node_pool", "update_mask")
    NODE_POOL_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    node_pool: NodePool
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, node_pool: _Optional[_Union[NodePool, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteNodePoolRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class BatchDeleteNodePoolsRequest(_message.Message):
    __slots__ = ("parent", "names")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    NAMES_FIELD_NUMBER: _ClassVar[int]
    parent: str
    names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, parent: _Optional[str] = ..., names: _Optional[_Iterable[str]] = ...) -> None: ...

class GetNodePoolStatsRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/model.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/model.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import billing_pb2 as gateway_dot_billing__pb2
from . import deployed_model_pb2 as gateway_dot_deployed__model__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gateway/model.proto\x12\x07gateway\x1a\x15gateway/billing.proto\x1a\x1cgateway/deployed_model.proto\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16google/type/date.proto\"\xaf\x0f\n\x05Model\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x14 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18  \x01(\tB\x05\xe2\x41\x02\x03\x05\x12*\n\x05state\x18\x06 \x01(\x0e\x32\x14.gateway.Model.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12(\n\x04kind\x18\x04 \x01(\x0e\x32\x13.gateway.Model.KindB\x05\xe2\x41\x02\x01\x05\x12\x18\n\ngithub_url\x18\x15 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1e\n\x10hugging_face_url\x18\x16 \x01(\tB\x04\xe2\x41\x01\x01\x12<\n\x12\x62\x61se_model_details\x18\x17 \x01(\x0b\x32\x19.gateway.BaseModelDetailsB\x05\xe2\x41\x02\x01\x05\x12\x31\n\x0cpeft_details\x18\x10 \x01(\x0b\x32\x14.gateway.PEFTDetailsB\x05\xe2\x41\x02\x01\x05\x12\x31\n\x0cteft_details\x18\x11 \x01(\x0b\x32\x14.gateway.TEFTDetailsB\x05\xe2\x41\x02\x01\x05\x12\x14\n\x06public\x18\x13 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12?\n\x13\x63onversation_config\x18\x18 \x01(\x0b\x32\x1b.gateway.ConversationConfigB\x05\xe2\x41\x02\x01\x05\x12\x1c\n\x0e\x63ontext_length\x18\x19 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\"\n\x14supports_image_input\x18\x1a \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1c\n\x0esupports_tools\x18\x1b \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1e\n\rimported_from\x18\x1c \x01(\tB\x07\x18\x01\xe2\x41\x02\x03\x05\x12*\n\x11tokens_per_second\x18\x1d \x01(\x05\x42\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12*\n\x11\x66\x65\x61tured_priority\x18\x1f \x01(\x05\x42\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x1e\n\x0f\x66ine_tuning_job\x18! \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x38\n\tsku_infos\x18\" \x03(\x0b\x32\x10.gateway.SKUInfoB\x13\x98\xf1\x04\x01\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12!\n\x13\x64\x65\x66\x61ult_draft_model\x18# \x01(\tB\x04\xe2\x41\x01\x01\x12\'\n\x19\x64\x65\x66\x61ult_draft_token_count\x18$ \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x38\n\nprecisions\x18& \x03(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x05\xe2\x41\x02\x01\x03\x12@\n\x13\x64\x65ployed_model_refs\x18% \x03(\x0b\x32\x19.gateway.DeployedModelRefB\x08\xe2\x41\x01\x03\x98\xf1\x04\x01\x12\x16\n\x07\x63luster\x18\' \x01(\tB\x05\xe2\x41\x02\x01\x03\x12\x31\n\x10\x64\x65precation_date\x18( \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01\x12\x18\n\ncalibrated\x18) \x01(\x08\x42\x04\xe2\x41\x01\x03\x12\x15\n\x07tunable\x18* \x01(\x08\x42\x04\xe2\x41\x01\x03\x12\x1b\n\rsupports_lora\x18+ \x01(\x08\x42\x04\xe2\x41\x01\x01\x12(\n\x1ause_hf_apply_chat_template\x18, \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x39\n\x15\x65xtra_deployment_args\x18- \x03(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18. \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12P\n\x17\x64\x65\x66\x61ult_sampling_params\x18/ \x03(\x0b\x32).gateway.Model.DefaultSamplingParamsEntryB\x04\xe2\x41\x01\x03\x12+\n\x07gcs_uri\x18\x30 \x01(\tB\x1a\xe2\x41\x01\x03\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x18\n\nrl_tunable\x18\x31 \x01(\x08\x42\x04\xe2\x41\x01\x03\x1a<\n\x1a\x44\x65\x66\x61ultSamplingParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"8\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\t\n\x05READY\x10\x06\"\xb1\x01\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x11\n\rHF_BASE_MODEL\x10\x01\x12\x11\n\rHF_PEFT_ADDON\x10\x02\x12\x11\n\rHF_TEFT_ADDON\x10\x03\x12\x16\n\x12\x46LUMINA_BASE_MODEL\x10\x04\x12\x11\n\rFLUMINA_ADDON\x10\x05\x12\x0f\n\x0b\x44RAFT_ADDON\x10\x06\x12\x0e\n\nFIRE_AGENT\x10\x07\x12\x0e\n\nLIVE_MERGE\x10\x08:`\xea\x41N\n\x16\x61pi.fireworks.ai/Model\x12%accounts/{AccountId}/models/{ModelId}*\x06models2\x05model\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\xf5\x02\n\x10\x42\x61seModelDetails\x12\x19\n\nworld_size\x18\x01 \x01(\x05\x42\x05\xe2\x41\x02\x01\x05\x12L\n\x11\x63heckpoint_format\x18\x02 \x01(\x0e\x32*.gateway.BaseModelDetails.CheckpointFormatB\x05\xe2\x41\x02\x01\x05\x12/\n\x11huggingface_files\x18\x03 \x03(\tB\x14\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x12\x17\n\x0fparameter_count\x18\x04 \x01(\x03\x12\x0b\n\x03moe\x18\x05 \x01(\x08\x12\x13\n\x07tunable\x18\x06 \x01(\x08\x42\x02\x18\x01\x12\x12\n\nmodel_type\x18\x07 \x01(\t\x12$\n\x16supports_fireattention\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x01\"R\n\x10\x43heckpointFormat\x12!\n\x1d\x43HECKPOINT_FORMAT_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x0f\n\x0bHUGGINGFACE\x10\x02\"\x9e\x01\n\x0bPEFTDetails\x12\x19\n\nbase_model\x18\x01 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x10\n\x01r\x18\x02 \x01(\x05\x42\x05\xe2\x41\x02\x02\x05\x12\x1d\n\x0etarget_modules\x18\x03 \x03(\tB\x05\xe2\x41\x02\x02\x05\x12\x1d\n\x0f\x62\x61se_model_type\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03\x12$\n\x16merge_addon_model_name\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\r\n\x0bTEFTDetails\"W\n\x12\x43onversationConfig\x12\x13\n\x05style\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x06system\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08template\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"~\n\x12\x43reateModelRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12#\n\x05model\x18\x02 \x01(\x0b\x32\x0e.gateway.ModelB\x04\xe2\x41\x01\x01\x12\x16\n\x08model_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07\x63luster\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"%\n\x0fGetModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"a\n\x13PrepareModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x36\n\tprecision\x18\x02 \x01(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x04\xe2\x41\x01\x01\"\xed\x01\n\x1dGetModelUploadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12Z\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32:.gateway.GetModelUploadEndpointRequest.FilenameToSizeEntryB\x04\xe2\x41\x01\x02\x12%\n\x17\x65nable_resumable_upload\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xe8\x02\n\x1eGetModelUploadEndpointResponse\x12\x62\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x41.gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry\x12\x66\n\x19\x66ilename_to_unsigned_uris\x18\x06 \x03(\x0b\x32\x43.gateway.GetModelUploadEndpointResponse.FilenameToUnsignedUrisEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a=\n\x1b\x46ilenameToUnsignedUrisEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x1fGetModelDownloadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xc5\x01\n GetModelDownloadEndpointResponse\x12\x64\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x43.gateway.GetModelDownloadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x1aValidateModelUploadRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x19skip_hf_config_validation\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01\"\xc0\x01\n\x11ListModelsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x34\n\x1binclude_deployed_model_refs\x18\x06 \x01(\x08\x42\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\"a\n\x12ListModelsResponse\x12\x1e\n\x06models\x18\x01 \x03(\x0b\x32\x0e.gateway.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"!\n\x1fListServerlessLoraModelsRequest\"2\n ListServerlessLoraModelsResponse\x12\x0e\n\x06models\x18\x01 \x03(\t\"\\\n\x1aValidateModelConfigRequest\x12\x19\n\x0b\x63onfig_json\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12#\n\x15tokenizer_config_json\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\"p\n\x12UpdateModelRequest\x12#\n\x05model\x18\x01 \x01(\x0b\x32\x0e.gateway.ModelB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"(\n\x12\x44\x65leteModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x94\x01\n\x10\x41wsS3ModelSource\x12\x17\n\ts3_bucket\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07s3_path\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08role_arn\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1b\n\raccess_key_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1b\n\raccess_secret\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"`\n\x12ImportModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x36\n\raws_s3_source\x18\x02 \x01(\x0b\x32\x19.gateway.AwsS3ModelSourceB\x04\xe2\x41\x01\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.model_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._loaded_options = None
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_MODEL'].fields_by_name['name']._loaded_options = None
  _globals['_MODEL'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['display_name']._loaded_options = None
  _globals['_MODEL'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['description']._loaded_options = None
  _globals['_MODEL'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['create_time']._loaded_options = None
  _globals['_MODEL'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['created_by']._loaded_options = None
  _globals['_MODEL'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['state']._loaded_options = None
  _globals['_MODEL'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['status']._loaded_options = None
  _globals['_MODEL'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['kind']._loaded_options = None
  _globals['_MODEL'].fields_by_name['kind']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['github_url']._loaded_options = None
  _globals['_MODEL'].fields_by_name['github_url']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['hugging_face_url']._loaded_options = None
  _globals['_MODEL'].fields_by_name['hugging_face_url']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['base_model_details']._loaded_options = None
  _globals['_MODEL'].fields_by_name['base_model_details']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['peft_details']._loaded_options = None
  _globals['_MODEL'].fields_by_name['peft_details']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['teft_details']._loaded_options = None
  _globals['_MODEL'].fields_by_name['teft_details']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['public']._loaded_options = None
  _globals['_MODEL'].fields_by_name['public']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['conversation_config']._loaded_options = None
  _globals['_MODEL'].fields_by_name['conversation_config']._serialized_options = b'\342A\002\001\005'
  _globals['_MODEL'].fields_by_name['context_length']._loaded_options = None
  _globals['_MODEL'].fields_by_name['context_length']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['supports_image_input']._loaded_options = None
  _globals['_MODEL'].fields_by_name['supports_image_input']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['supports_tools']._loaded_options = None
  _globals['_MODEL'].fields_by_name['supports_tools']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['imported_from']._loaded_options = None
  _globals['_MODEL'].fields_by_name['imported_from']._serialized_options = b'\030\001\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['tokens_per_second']._loaded_options = None
  _globals['_MODEL'].fields_by_name['tokens_per_second']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_MODEL'].fields_by_name['featured_priority']._loaded_options = None
  _globals['_MODEL'].fields_by_name['featured_priority']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_MODEL'].fields_by_name['fine_tuning_job']._loaded_options = None
  _globals['_MODEL'].fields_by_name['fine_tuning_job']._serialized_options = b'\342A\002\003\005'
  _globals['_MODEL'].fields_by_name['sku_infos']._loaded_options = None
  _globals['_MODEL'].fields_by_name['sku_infos']._serialized_options = b'\230\361\004\001\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_MODEL'].fields_by_name['default_draft_model']._loaded_options = None
  _globals['_MODEL'].fields_by_name['default_draft_model']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['default_draft_token_count']._loaded_options = None
  _globals['_MODEL'].fields_by_name['default_draft_token_count']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['precisions']._loaded_options = None
  _globals['_MODEL'].fields_by_name['precisions']._serialized_options = b'\342A\002\001\003'
  _globals['_MODEL'].fields_by_name['deployed_model_refs']._loaded_options = None
  _globals['_MODEL'].fields_by_name['deployed_model_refs']._serialized_options = b'\342A\001\003\230\361\004\001'
  _globals['_MODEL'].fields_by_name['cluster']._loaded_options = None
  _globals['_MODEL'].fields_by_name['cluster']._serialized_options = b'\342A\002\001\003'
  _globals['_MODEL'].fields_by_name['deprecation_date']._loaded_options = None
  _globals['_MODEL'].fields_by_name['deprecation_date']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['calibrated']._loaded_options = None
  _globals['_MODEL'].fields_by_name['calibrated']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['tunable']._loaded_options = None
  _globals['_MODEL'].fields_by_name['tunable']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['supports_lora']._loaded_options = None
  _globals['_MODEL'].fields_by_name['supports_lora']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['use_hf_apply_chat_template']._loaded_options = None
  _globals['_MODEL'].fields_by_name['use_hf_apply_chat_template']._serialized_options = b'\342A\001\001'
  _globals['_MODEL'].fields_by_name['extra_deployment_args']._loaded_options = None
  _globals['_MODEL'].fields_by_name['extra_deployment_args']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_MODEL'].fields_by_name['update_time']._loaded_options = None
  _globals['_MODEL'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['default_sampling_params']._loaded_options = None
  _globals['_MODEL'].fields_by_name['default_sampling_params']._serialized_options = b'\342A\001\003'
  _globals['_MODEL'].fields_by_name['gcs_uri']._loaded_options = None
  _globals['_MODEL'].fields_by_name['gcs_uri']._serialized_options = b'\342A\001\003\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_MODEL'].fields_by_name['rl_tunable']._loaded_options = None
  _globals['_MODEL'].fields_by_name['rl_tunable']._serialized_options = b'\342A\001\003'
  _globals['_MODEL']._loaded_options = None
  _globals['_MODEL']._serialized_options = b'\352AN\n\026api.fireworks.ai/Model\022%accounts/{AccountId}/models/{ModelId}*\006models2\005model\202\361\004\013\n\007Account\030\001'
  _globals['_BASEMODELDETAILS'].fields_by_name['world_size']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['world_size']._serialized_options = b'\342A\002\001\005'
  _globals['_BASEMODELDETAILS'].fields_by_name['checkpoint_format']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['checkpoint_format']._serialized_options = b'\342A\002\001\005'
  _globals['_BASEMODELDETAILS'].fields_by_name['huggingface_files']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['huggingface_files']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_BASEMODELDETAILS'].fields_by_name['tunable']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['tunable']._serialized_options = b'\030\001'
  _globals['_BASEMODELDETAILS'].fields_by_name['supports_fireattention']._loaded_options = None
  _globals['_BASEMODELDETAILS'].fields_by_name['supports_fireattention']._serialized_options = b'\342A\001\001'
  _globals['_PEFTDETAILS'].fields_by_name['base_model']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTDETAILS'].fields_by_name['r']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['r']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTDETAILS'].fields_by_name['target_modules']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['target_modules']._serialized_options = b'\342A\002\002\005'
  _globals['_PEFTDETAILS'].fields_by_name['base_model_type']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['base_model_type']._serialized_options = b'\342A\001\003'
  _globals['_PEFTDETAILS'].fields_by_name['merge_addon_model_name']._loaded_options = None
  _globals['_PEFTDETAILS'].fields_by_name['merge_addon_model_name']._serialized_options = b'\342A\001\001'
  _globals['_CONVERSATIONCONFIG'].fields_by_name['style']._loaded_options = None
  _globals['_CONVERSATIONCONFIG'].fields_by_name['style']._serialized_options = b'\342A\001\002'
  _globals['_CONVERSATIONCONFIG'].fields_by_name['system']._loaded_options = None
  _globals['_CONVERSATIONCONFIG'].fields_by_name['system']._serialized_options = b'\342A\001\001'
  _globals['_CONVERSATIONCONFIG'].fields_by_name['template']._loaded_options = None
  _globals['_CONVERSATIONCONFIG'].fields_by_name['template']._serialized_options = b'\342A\001\001'
  _globals['_CREATEMODELREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEMODELREQUEST'].fields_by_name['model']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['model']._serialized_options = b'\342A\001\001'
  _globals['_CREATEMODELREQUEST'].fields_by_name['model_id']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _globals['_CREATEMODELREQUEST'].fields_by_name['cluster']._loaded_options = None
  _globals['_CREATEMODELREQUEST'].fields_by_name['cluster']._serialized_options = b'\342A\001\001'
  _globals['_GETMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREPAREMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_PREPAREMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREPAREMODELREQUEST'].fields_by_name['precision']._loaded_options = None
  _globals['_PREPAREMODELREQUEST'].fields_by_name['precision']._serialized_options = b'\342A\001\001'
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_options = b'8\001'
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._serialized_options = b'\342A\001\002'
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['enable_resumable_upload']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTREQUEST'].fields_by_name['enable_resumable_upload']._serialized_options = b'\342A\001\001'
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._loaded_options = None
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._serialized_options = b'8\001'
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['skip_hf_config_validation']._loaded_options = None
  _globals['_VALIDATEMODELUPLOADREQUEST'].fields_by_name['skip_hf_config_validation']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTMODELSREQUEST'].fields_by_name['include_deployed_model_refs']._loaded_options = None
  _globals['_LISTMODELSREQUEST'].fields_by_name['include_deployed_model_refs']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['config_json']._loaded_options = None
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['config_json']._serialized_options = b'\342A\001\002'
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['tokenizer_config_json']._loaded_options = None
  _globals['_VALIDATEMODELCONFIGREQUEST'].fields_by_name['tokenizer_config_json']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEMODELREQUEST'].fields_by_name['model']._loaded_options = None
  _globals['_UPDATEMODELREQUEST'].fields_by_name['model']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEMODELREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEMODELREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_bucket']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_bucket']._serialized_options = b'\342A\001\002'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_path']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['s3_path']._serialized_options = b'\342A\001\001'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['role_arn']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['role_arn']._serialized_options = b'\342A\001\001'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_key_id']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_key_id']._serialized_options = b'\342A\001\001'
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_secret']._loaded_options = None
  _globals['_AWSS3MODELSOURCE'].fields_by_name['access_secret']._serialized_options = b'\342A\001\001'
  _globals['_IMPORTMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_IMPORTMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_IMPORTMODELREQUEST'].fields_by_name['aws_s3_source']._loaded_options = None
  _globals['_IMPORTMODELREQUEST'].fields_by_name['aws_s3_source']._serialized_options = b'\342A\001\001'
  _globals['_MODEL']._serialized_start=337
  _globals['_MODEL']._serialized_end=2304
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._serialized_start=1908
  _globals['_MODEL_DEFAULTSAMPLINGPARAMSENTRY']._serialized_end=1968
  _globals['_MODEL_STATE']._serialized_start=1970
  _globals['_MODEL_STATE']._serialized_end=2026
  _globals['_MODEL_KIND']._serialized_start=2029
  _globals['_MODEL_KIND']._serialized_end=2206
  _globals['_BASEMODELDETAILS']._serialized_start=2307
  _globals['_BASEMODELDETAILS']._serialized_end=2680
  _globals['_BASEMODELDETAILS_CHECKPOINTFORMAT']._serialized_start=2598
  _globals['_BASEMODELDETAILS_CHECKPOINTFORMAT']._serialized_end=2680
  _globals['_PEFTDETAILS']._serialized_start=2683
  _globals['_PEFTDETAILS']._serialized_end=2841
  _globals['_TEFTDETAILS']._serialized_start=2843
  _globals['_TEFTDETAILS']._serialized_end=2856
  _globals['_CONVERSATIONCONFIG']._serialized_start=2858
  _globals['_CONVERSATIONCONFIG']._serialized_end=2945
  _globals['_CREATEMODELREQUEST']._serialized_start=2947
  _globals['_CREATEMODELREQUEST']._serialized_end=3073
  _globals['_GETMODELREQUEST']._serialized_start=3075
  _globals['_GETMODELREQUEST']._serialized_end=3112
  _globals['_PREPAREMODELREQUEST']._serialized_start=3114
  _globals['_PREPAREMODELREQUEST']._serialized_end=3211
  _globals['_GETMODELUPLOADENDPOINTREQUEST']._serialized_start=3214
  _globals['_GETMODELUPLOADENDPOINTREQUEST']._serialized_end=3451
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_start=3398
  _globals['_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_end=3451
  _globals['_GETMODELUPLOADENDPOINTRESPONSE']._serialized_start=3454
  _globals['_GETMODELUPLOADENDPOINTRESPONSE']._serialized_end=3814
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=3692
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=3751
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._serialized_start=3753
  _globals['_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOUNSIGNEDURISENTRY']._serialized_end=3814
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST']._serialized_start=3816
  _globals['_GETMODELDOWNLOADENDPOINTREQUEST']._serialized_end=3869
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE']._serialized_start=3872
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE']._serialized_end=4069
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=3692
  _globals['_GETMODELDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=3751
  _globals['_VALIDATEMODELUPLOADREQUEST']._serialized_start=4071
  _globals['_VALIDATEMODELUPLOADREQUEST']._serialized_end=4160
  _globals['_LISTMODELSREQUEST']._serialized_start=4163
  _globals['_LISTMODELSREQUEST']._serialized_end=4355
  _globals['_LISTMODELSRESPONSE']._serialized_start=4357
  _globals['_LISTMODELSRESPONSE']._serialized_end=4454
  _globals['_LISTSERVERLESSLORAMODELSREQUEST']._serialized_start=4456
  _globals['_LISTSERVERLESSLORAMODELSREQUEST']._serialized_end=4489
  _globals['_LISTSERVERLESSLORAMODELSRESPONSE']._serialized_start=4491
  _globals['_LISTSERVERLESSLORAMODELSRESPONSE']._serialized_end=4541
  _globals['_VALIDATEMODELCONFIGREQUEST']._serialized_start=4543
  _globals['_VALIDATEMODELCONFIGREQUEST']._serialized_end=4635
  _globals['_UPDATEMODELREQUEST']._serialized_start=4637
  _globals['_UPDATEMODELREQUEST']._serialized_end=4749
  _globals['_DELETEMODELREQUEST']._serialized_start=4751
  _globals['_DELETEMODELREQUEST']._serialized_end=4791
  _globals['_AWSS3MODELSOURCE']._serialized_start=4794
  _globals['_AWSS3MODELSOURCE']._serialized_end=4942
  _globals['_IMPORTMODELREQUEST']._serialized_start=4944
  _globals['_IMPORTMODELREQUEST']._serialized_end=5040
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/batch_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/batch_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/batch_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\t\n\x08\x42\x61tchJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\t \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x33\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\r \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\x0cnode_pool_id\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1d\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1a\n\x0bsnapshot_id\x18\x13 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x18\n\tnum_ranks\x18\x0b \x01(\x05\x42\x05\xe2\x41\x02\x01\x05\x12\x37\n\x08\x65nv_vars\x18\x06 \x03(\x0b\x32\x1e.gateway.BatchJob.EnvVarsEntryB\x05\xe2\x41\x02\x01\x05\x12\x13\n\x04role\x18\x11 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x32\n\x0fpython_executor\x18\x07 \x01(\x0b\x32\x17.gateway.PythonExecutorH\x00\x12\x36\n\x11notebook_executor\x18\x08 \x01(\x0b\x32\x19.gateway.NotebookExecutorH\x00\x12\x30\n\x0eshell_executor\x18\x10 \x01(\x0b\x32\x16.gateway.ShellExecutorH\x00\x12\x18\n\timage_ref\x18\n \x01(\tB\x05\xe2\x41\x02\x01\x05\x12>\n\x0b\x61nnotations\x18\x12 \x03(\x0b\x32\".gateway.BatchJob.AnnotationsEntryB\x05\xe2\x41\x02\x01\x05\x12-\n\x05state\x18\x04 \x01(\x0e\x32\x17.gateway.BatchJob.StateB\x05\xe2\x41\x02\x03\x05\x12\x15\n\x06status\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x0e\n\x06shared\x18\x14 \x01(\x08\x12\x35\n\x0bupdate_time\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x07\x12\n\n\x06QUEUED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0e\n\nCANCELLING\x10\x08\x12\r\n\tCANCELLED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\t:\x84\x01\xea\x41r\n\x19\x61pi.fireworks.ai/BatchJob\x12@accounts/{AccountId}/clusters/{ClusterId}/batchJobs/{BatchJobId}*\tbatchJobs2\x08\x62\x61tchJob\x82\xf1\x04\x0b\n\x07\x43luster\x10\x01\x42\x0f\n\rexecutor_type\"Y\n\x15\x43reateBatchJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12*\n\tbatch_job\x18\x02 \x01(\x0b\x32\x11.gateway.BatchJobB\x04\xe2\x41\x01\x02\"(\n\x12GetBatchJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8d\x01\n\x14ListBatchJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"k\n\x15ListBatchJobsResponse\x12%\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x11.gateway.BatchJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"z\n\x15UpdateBatchJobRequest\x12*\n\tbatch_job\x18\x01 \x01(\x0b\x32\x11.gateway.BatchJobB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"+\n\x15\x44\x65leteBatchJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"H\n\x1b\x42\x61tchDeleteBatchJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05names\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"+\n\x15\x43\x61ncelBatchJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xd9\x01\n\x16GetBatchJobLogsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\r\n\x05ranks\x18\x03 \x03(\x05\x12\x17\n\tpage_size\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x34\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1d\n\x0fstart_from_head\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x01\"V\n\x17GetBatchJobLogsResponse\x12\"\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x11.gateway.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xbe\x01\n\x0ePythonExecutor\x12=\n\x0btarget_type\x18\x01 \x01(\x0e\x32\".gateway.PythonExecutor.TargetTypeB\x04\xe2\x41\x01\x02\x12\x14\n\x06target\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04\x61rgs\x18\x03 \x03(\tB\x04\xe2\x41\x01\x01\"C\n\nTargetType\x12\x1b\n\x17TARGET_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MODULE\x10\x01\x12\x0c\n\x08\x46ILENAME\x10\x02\"&\n\rShellExecutor\x12\x15\n\x07\x63ommand\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"3\n\x10NotebookExecutor\x12\x1f\n\x11notebook_filename\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"W\n\x08LogEntry\x12,\n\x08log_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rank\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.batch_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_BATCHJOB_ENVVARSENTRY']._loaded_options = None
  _globals['_BATCHJOB_ENVVARSENTRY']._serialized_options = b'8\001'
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_BATCHJOB'].fields_by_name['name']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_BATCHJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['start_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['start_time']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['end_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['end_time']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['node_pool_id']._serialized_options = b'\342A\002\002\005'
  _globals['_BATCHJOB'].fields_by_name['environment_id']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['environment_id']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['snapshot_id']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['snapshot_id']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['num_ranks']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['num_ranks']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['env_vars']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['env_vars']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['role']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['role']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['image_ref']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['image_ref']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['annotations']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['annotations']._serialized_options = b'\342A\002\001\005'
  _globals['_BATCHJOB'].fields_by_name['state']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['status']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_BATCHJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_BATCHJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_BATCHJOB']._loaded_options = None
  _globals['_BATCHJOB']._serialized_options = b'\352Ar\n\031api.fireworks.ai/BatchJob\022@accounts/{AccountId}/clusters/{ClusterId}/batchJobs/{BatchJobId}*\tbatchJobs2\010batchJob\202\361\004\013\n\007Cluster\020\001'
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['batch_job']._loaded_options = None
  _globals['_CREATEBATCHJOBREQUEST'].fields_by_name['batch_job']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBATCHJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTBATCHJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['batch_job']._loaded_options = None
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['batch_job']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEBATCHJOBREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEBATCHJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEBATCHJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['names']._loaded_options = None
  _globals['_BATCHDELETEBATCHJOBSREQUEST'].fields_by_name['names']._serialized_options = b'\342A\001\002'
  _globals['_CANCELBATCHJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CANCELBATCHJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_from_head']._loaded_options = None
  _globals['_GETBATCHJOBLOGSREQUEST'].fields_by_name['start_from_head']._serialized_options = b'\342A\001\001'
  _globals['_PYTHONEXECUTOR'].fields_by_name['target_type']._loaded_options = None
  _globals['_PYTHONEXECUTOR'].fields_by_name['target_type']._serialized_options = b'\342A\001\002'
  _globals['_PYTHONEXECUTOR'].fields_by_name['target']._loaded_options = None
  _globals['_PYTHONEXECUTOR'].fields_by_name['target']._serialized_options = b'\342A\001\002'
  _globals['_PYTHONEXECUTOR'].fields_by_name['args']._loaded_options = None
  _globals['_PYTHONEXECUTOR'].fields_by_name['args']._serialized_options = b'\342A\001\001'
  _globals['_SHELLEXECUTOR'].fields_by_name['command']._loaded_options = None
  _globals['_SHELLEXECUTOR'].fields_by_name['command']._serialized_options = b'\342A\001\002'
  _globals['_NOTEBOOKEXECUTOR'].fields_by_name['notebook_filename']._loaded_options = None
  _globals['_NOTEBOOKEXECUTOR'].fields_by_name['notebook_filename']._serialized_options = b'\342A\001\002'
  _globals['_BATCHJOB']._serialized_start=187
  _globals['_BATCHJOB']._serialized_end=1427
  _globals['_BATCHJOB_ENVVARSENTRY']._serialized_start=1020
  _globals['_BATCHJOB_ENVVARSENTRY']._serialized_end=1066
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._serialized_start=1068
  _globals['_BATCHJOB_ANNOTATIONSENTRY']._serialized_end=1118
  _globals['_BATCHJOB_STATE']._serialized_start=1121
  _globals['_BATCHJOB_STATE']._serialized_end=1275
  _globals['_CREATEBATCHJOBREQUEST']._serialized_start=1429
  _globals['_CREATEBATCHJOBREQUEST']._serialized_end=1518
  _globals['_GETBATCHJOBREQUEST']._serialized_start=1520
  _globals['_GETBATCHJOBREQUEST']._serialized_end=1560
  _globals['_LISTBATCHJOBSREQUEST']._serialized_start=1563
  _globals['_LISTBATCHJOBSREQUEST']._serialized_end=1704
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_start=1706
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_end=1813
  _globals['_UPDATEBATCHJOBREQUEST']._serialized_start=1815
  _globals['_UPDATEBATCHJOBREQUEST']._serialized_end=1937
  _globals['_DELETEBATCHJOBREQUEST']._serialized_start=1939
  _globals['_DELETEBATCHJOBREQUEST']._serialized_end=1982
  _globals['_BATCHDELETEBATCHJOBSREQUEST']._serialized_start=1984
  _globals['_BATCHDELETEBATCHJOBSREQUEST']._serialized_end=2056
  _globals['_CANCELBATCHJOBREQUEST']._serialized_start=2058
  _globals['_CANCELBATCHJOBREQUEST']._serialized_end=2101
  _globals['_GETBATCHJOBLOGSREQUEST']._serialized_start=2104
  _globals['_GETBATCHJOBLOGSREQUEST']._serialized_end=2321
  _globals['_GETBATCHJOBLOGSRESPONSE']._serialized_start=2323
  _globals['_GETBATCHJOBLOGSRESPONSE']._serialized_end=2409
  _globals['_PYTHONEXECUTOR']._serialized_start=2412
  _globals['_PYTHONEXECUTOR']._serialized_end=2602
  _globals['_PYTHONEXECUTOR_TARGETTYPE']._serialized_start=2535
  _globals['_PYTHONEXECUTOR_TARGETTYPE']._serialized_end=2602
  _globals['_SHELLEXECUTOR']._serialized_start=2604
  _globals['_SHELLEXECUTOR']._serialized_end=2642
  _globals['_NOTEBOOKEXECUTOR']._serialized_start=2644
  _globals['_NOTEBOOKEXECUTOR']._serialized_end=2695
  _globals['_LOGENTRY']._serialized_start=2697
  _globals['_LOGENTRY']._serialized_end=2784
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/aws_iam_role_binding.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/aws_iam_role_binding.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"gateway/aws_iam_role_binding.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x93\x01\n\x11\x41wsIamRoleBinding\x12\x19\n\naccount_id\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x17\n\tprincipal\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04role\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\"v\n\x1e\x43reateAwsIamRoleBindingRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12>\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x04\xe2\x41\x01\x02\"\x96\x01\n\x1dListAwsIamRoleBindingsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x88\x01\n\x1eListAwsIamRoleBindingsResponse\x12\x39\n\x15\x61ws_iam_role_bindings\x18\x01 \x03(\x0b\x32\x1a.gateway.AwsIamRoleBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"`\n\x1e\x44\x65leteAwsIamRoleBindingRequest\x12>\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.aws_iam_role_binding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_AWSIAMROLEBINDING'].fields_by_name['account_id']._loaded_options = None
  _globals['_AWSIAMROLEBINDING'].fields_by_name['account_id']._serialized_options = b'\342A\002\003\005'
  _globals['_AWSIAMROLEBINDING'].fields_by_name['create_time']._loaded_options = None
  _globals['_AWSIAMROLEBINDING'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_AWSIAMROLEBINDING'].fields_by_name['principal']._loaded_options = None
  _globals['_AWSIAMROLEBINDING'].fields_by_name['principal']._serialized_options = b'\342A\001\002'
  _globals['_AWSIAMROLEBINDING'].fields_by_name['role']._loaded_options = None
  _globals['_AWSIAMROLEBINDING'].fields_by_name['role']._serialized_options = b'\342A\001\002'
  _globals['_CREATEAWSIAMROLEBINDINGREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEAWSIAMROLEBINDINGREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEAWSIAMROLEBINDINGREQUEST'].fields_by_name['aws_iam_role_binding']._loaded_options = None
  _globals['_CREATEAWSIAMROLEBINDINGREQUEST'].fields_by_name['aws_iam_role_binding']._serialized_options = b'\342A\001\002'
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEAWSIAMROLEBINDINGREQUEST'].fields_by_name['aws_iam_role_binding']._loaded_options = None
  _globals['_DELETEAWSIAMROLEBINDINGREQUEST'].fields_by_name['aws_iam_role_binding']._serialized_options = b'\342A\001\002'
  _globals['_AWSIAMROLEBINDING']._serialized_start=114
  _globals['_AWSIAMROLEBINDING']._serialized_end=261
  _globals['_CREATEAWSIAMROLEBINDINGREQUEST']._serialized_start=263
  _globals['_CREATEAWSIAMROLEBINDINGREQUEST']._serialized_end=381
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST']._serialized_start=384
  _globals['_LISTAWSIAMROLEBINDINGSREQUEST']._serialized_end=534
  _globals['_LISTAWSIAMROLEBINDINGSRESPONSE']._serialized_start=537
  _globals['_LISTAWSIAMROLEBINDINGSRESPONSE']._serialized_end=673
  _globals['_DELETEAWSIAMROLEBINDINGREQUEST']._serialized_start=675
  _globals['_DELETEAWSIAMROLEBINDINGREQUEST']._serialized_end=771
# @@protoc_insertion_point(module_scope)



from typing import Optional, Type
import json
from pydantic import BaseModel
from .api_client import FireworksClient
from .error import InvalidRequestError
from .api import EmbeddingResponse


class Embedding:
    """
    Base class for handling embeddings. This class provides logic for creating embedding
    both synchronously and asynchronously.

    Attributes:
      endpoint (str): API endpoint for the completion request.
      response_class (Type): Class used for parsing the non-streaming response.
    """

    endpoint = "embeddings"  # Matching the API reference
    response_class = EmbeddingResponse

    @classmethod
    def create(
        cls,
        model,
        input=None,
        request_timeout=600,
        client: Optional[FireworksClient] = None,
        **kwargs,
    ):
        """
        Create an embedding response

        Args:
          model (str): Model name to use for the completion.
          input (str): The input string for embedding.
          request_timeout (int, optional): Request timeout in seconds. Defaults to 600.
          **kwargs: Additional keyword arguments.

        Returns:
          EmbeddingResponse: response for embedding request
        """
        data_key = cls._get_data_key()
        if input:
            kwargs[data_key] = input

        cls._validate_kwargs(kwargs)

        return cls._create_non_streaming(
            model, request_timeout, client=client, **kwargs
        )

    @classmethod
    def acreate(
        cls,
        model,
        input=None,
        request_timeout=600,
        client: Optional[FireworksClient] = None,
        **kwargs,
    ):
        """
        Asynchronously create a completion.

        Args:
        Create an embedding response

        Args:
          model (str): Model name to use for the completion.
          input (str): The input string for embedding.
          request_timeout (int, optional): Request timeout in seconds. Defaults to 600.
          **kwargs: Additional keyword arguments.

        Returns:
          AsyncGenerator[EmbeddingResponse]: async response for embedding request
        """
        data_key = cls._get_data_key()
        if input:
            kwargs[data_key] = input
        cls._validate_kwargs(kwargs)

        return cls._acreate_non_streaming(
            model, request_timeout, client=client, **kwargs
        )

    @classmethod
    def _validate_kwargs(cls, kwargs):
        assert cls._get_data_key() in kwargs, f"{cls._get_data_key()} must be provided"

    @classmethod
    def _get_data_key(cls) -> str:
        return "input"

    @classmethod
    def _create_non_streaming(
        cls,
        model: str,
        request_timeout=600,
        client: Optional[FireworksClient] = None,
        **kwargs,
    ):
        client = client or FireworksClient(request_timeout=request_timeout)
        data = {"model": model, **kwargs}
        response = client.post_request_non_streaming(
            f"{client.base_url}/{cls.endpoint}", data=data
        )
        return cls.response_class(**response)

    @classmethod
    async def _acreate_non_streaming(
        cls,
        model: str,
        request_timeout=600,
        client: Optional[FireworksClient] = None,
        **kwargs,
    ):
        client = client or FireworksClient(request_timeout=request_timeout)
        data = {"model": model, "stream": False, **kwargs}
        response = await client.post_request_async_non_streaming(
            f"{client.base_url}/{cls.endpoint}", data=data
        )
        return cls.response_class(**response)


class EmbeddingV1(Embedding):
    def __init__(self, client: FireworksClient):
        self._client = client

    def create(
        self,
        model,
        input=None,
        request_timeout=600,
        **kwargs,
    ):
        return super().create(
            model,
            input,
            request_timeout,
            client=self._client,
            **kwargs,
        )

    def acreate(
        self,
        model,
        input=None,
        request_timeout=600,
        **kwargs,
    ):
        return super().acreate(
            model,
            input,
            request_timeout,
            client=self._client,
            **kwargs,
        )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google/rpc/status.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Status",)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto


@dataclass(eq=False, repr=False)
class Status(betterproto.Message):
    """
    The `Status` type defines a logical error model that is suitable for
    different programming environments, including REST APIs and RPC APIs. It is
    used by [gRPC](https://github.com/grpc). Each `Status` message contains
    three pieces of data: error code, error message, and error details.

    You can find out more about this error model and how to work with it in the
    [API Design Guide](https://cloud.google.com/apis/design/errors).
    """

    code: int = betterproto.int32_field(1)
    """
    The status code, which should be an enum value of
    [google.rpc.Code][google.rpc.Code].
    """

    message: str = betterproto.string_field(2)
    """
    A developer-facing error message, which should be in English. Any
    user-facing error message should be localized and sent in the
    [google.rpc.Status.details][google.rpc.Status.details] field, or localized
    by the client.
    """

    details: List["betterproto_lib_google_protobuf.Any"] = betterproto.message_field(3)
    """
    A list of messages that carry the error details.  There is a common set of
    message types for APIs to use.
    """


import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/inference_log.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/inference_log.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgateway/inference_log.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xab\x04\n\x0cInferenceLog\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x13\n\x05model\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03\x12\x1a\n\x0crequest_type\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03\x12\x1b\n\rinput_content\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03\x12\x1c\n\x0eoutput_content\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03\x12\x19\n\x0b\x64uration_ms\x18\x07 \x01(\x03\x42\x04\xe2\x41\x01\x03\x12\x19\n\x0bstatus_code\x18\x08 \x01(\x05\x42\x04\xe2\x41\x01\x03\x12;\n\x08metadata\x18\t \x03(\x0b\x32#.gateway.InferenceLog.MetadataEntryB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x86\x01\xea\x41t\n\x1d\x61pi.fireworks.ai/InferenceLog\x12\x34\x61\x63\x63ounts/{AccountId}/inference-logs/{InferenceLogId}*\x0einference-logs2\rinference-log\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x10\x01\",\n\x16GetInferenceLogRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"/\n\x19\x44\x65leteInferenceLogRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x91\x01\n\x18ListInferenceLogsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"w\n\x19ListInferenceLogsResponse\x12-\n\x0einference_logs\x18\x01 \x03(\x0b\x32\x15.gateway.InferenceLog\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.inference_log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_INFERENCELOG_METADATAENTRY']._loaded_options = None
  _globals['_INFERENCELOG_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INFERENCELOG'].fields_by_name['name']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_INFERENCELOG'].fields_by_name['create_time']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_INFERENCELOG'].fields_by_name['model']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['model']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG'].fields_by_name['request_type']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['request_type']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG'].fields_by_name['input_content']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['input_content']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG'].fields_by_name['output_content']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['output_content']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG'].fields_by_name['duration_ms']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['duration_ms']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG'].fields_by_name['status_code']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['status_code']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG'].fields_by_name['metadata']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['metadata']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG'].fields_by_name['update_time']._loaded_options = None
  _globals['_INFERENCELOG'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_INFERENCELOG']._loaded_options = None
  _globals['_INFERENCELOG']._serialized_options = b'\352At\n\035api.fireworks.ai/InferenceLog\0224accounts/{AccountId}/inference-logs/{InferenceLogId}*\016inference-logs2\rinference-log\202\361\004\013\n\007Account\020\001'
  _globals['_GETINFERENCELOGREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETINFERENCELOGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DELETEINFERENCELOGREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEINFERENCELOGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTINFERENCELOGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_INFERENCELOG']._serialized_start=157
  _globals['_INFERENCELOG']._serialized_end=712
  _globals['_INFERENCELOG_METADATAENTRY']._serialized_start=528
  _globals['_INFERENCELOG_METADATAENTRY']._serialized_end=575
  _globals['_GETINFERENCELOGREQUEST']._serialized_start=714
  _globals['_GETINFERENCELOGREQUEST']._serialized_end=758
  _globals['_DELETEINFERENCELOGREQUEST']._serialized_start=760
  _globals['_DELETEINFERENCELOGREQUEST']._serialized_end=807
  _globals['_LISTINFERENCELOGSREQUEST']._serialized_start=810
  _globals['_LISTINFERENCELOGSREQUEST']._serialized_end=955
  _globals['_LISTINFERENCELOGSRESPONSE']._serialized_start=957
  _globals['_LISTINFERENCELOGSRESPONSE']._serialized_end=1076
# @@protoc_insertion_point(module_scope)
